@@ -1,4 +1,6 @@
-"""
+
+__long_description__ = """\
+
 ▒▓▒▓▒▓▒▓▒▓▒▓▒▓▒▓▒▓▒▓▒▓▒▓▒▓▒▓▒▓▒▓▒▓▒▓▒▓▒▓▒▓▒▓▒
  ▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒
  ▒▒▒▒▒▒▒▒██████╗▒▒██╗▒██████╗████████╗▒▒▒▒▒▒
@@ -14,20 +16,32 @@
     Another earth-shattering invention
     UltrafunkAmsterdam (c) 2021
 
-"""
-__description__ = """
-d1ct is a hybrid object/mapping. In contrast to some other attempts
-from developers, this one is json serializable, subclassable, metaclassable,
-dict attribute accessible, **unpackable, interchangable with dict and back.
+    d1ct is a hybrid object/mapping. In contrast to some other attempts
+    from several projects, this one is json serializable, subclassable, metaclassable,
+    attribute-accessible, **unpackable, interchangable with dict and back.
 
-Oh minor detail: it is recursive, and autocomplete works in 95% of the cases, even if it comes from a list.
+    Oh minor detail: it is recursive, and autocomplete in your interactive shell works
+    in 95% of the cases, even if it's list-nested.
+
+    version 1.0.5
+        - added the capability to not only accept dict-like mappings, but also lists of objects
+          which will be returned as a list of d1ct-objects \
 """
-__version__ = "1.0.0"
+
+__description__ = "dict implementation supporting attribute access, recursion, json, hashable, subclass, metaclass"
+__version__ = "1.0.5"
 
 from collections.abc import Sequence, Mapping
 
+class d1ct(dict):
+
+    def __new__(cls, *a, **kw):
+        if hasattr(a, '__len__'):
+            if len(a) > 0:
+                if isinstance(a[0], (list, tuple)):
+                    return [D1ct(_) for _ in a[0]]
+        return super().__new__(cls)
 
-class D1ct(dict):
     def __init__(self, *a, **kw):
         """
         One of the only data types in python which is:
@@ -47,6 +61,7 @@ class D1ct(dict):
         *a
         **kw
         """
+
         super(D1ct, self).__init__(*a, **kw)
         object.__setattr__(self, "__dict__", self)
         for k, v in self.items():
@@ -96,15 +111,7 @@ class D1ct(dict):
 
     def update(self, *a, **kw):
         """
-        small change compared to dicts .update method
-        Parameters
-        ----------
-        *a
-        **kw
-
-        Returns
-        -------
-
+        like dict.update()
         """
         d = {}
         if len(a) > 0:
@@ -125,9 +132,10 @@ class D1ct(dict):
         return object.__dir__(self) + list(super(D1ct, self).keys())
 
 
-D1ct.__doc__ = __description__
-D1ct.__version__ = __version__
 
+d1ct.__module__ = None
+d1ct.__doc__ = __description__
+d1ct.__version__ = __version__
+D1ct = d1ct
 import sys
-
-sys.modules[__name__] = D1ct
+sys.modules[__name__] = d1ct
